@@ -94,7 +94,7 @@ class ConfigZone:
             "hold_activity": self.hold_activity,
             "hold": self.hold,
             "hold_until": self.hold_until,
-            "activities": list(map(lambda activity: activity.__repr__(), self.activities)),
+            "activities": [activity.__repr__() for activity in self.activities],
         }
         if self.hold_activity is not None:
             builder["hold_activity"] = self.hold_activity.value
@@ -125,6 +125,7 @@ class Config:
         self.raw_config_json = self.system.api_connection.get_config(
             system_serial=self.system.serial
         )
+        _LOGGER.debug(f"raw_config_json:{self.raw_config_json}")
         self.temperature_unit = safely_get_json_value(self.raw_config_json, "cfgem")
         self.static_pressure = safely_get_json_value(self.raw_config_json, "staticPressure")
         self.mode = safely_get_json_value(self.raw_config_json, "mode")
@@ -152,7 +153,7 @@ class Config:
             "limit_min": self.limit_min,
             "limit_max": self.limit_max,
             "time_stamp": self.time_stamp.astimezone().strftime("%m/%d/%Y, %H:%M:%S %Z"),
-            "zones": list(map(lambda zone: zone.__repr__(), self.zones)),
+            "zones": [zone.__repr__() for zone in self.zones],
         }
 
     def __str__(self):
